/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.piwiktracking.service.repository;

import se.vgregion.dao.domain.patterns.repository.db.jpa.DefaultJpaRepository;
import se.vgregion.portal.piwiktracking.domain.jpa.PiwikTracking;

import java.util.List;

/**
 * Implementation of {@link JpaPiwikTrackingRepository}.
 *
 * @author Erik Andersson
 * @company Monator Technologies AB
 */
public class JpaPiwikTrackingRepositoryImpl extends DefaultJpaRepository<PiwikTracking, Long>
        implements JpaPiwikTrackingRepository {
	
    @Override
    public PiwikTracking findPiwikTracking(long id) {

    	PiwikTracking piwikTracking = findByPrimaryKey(id);

        return piwikTracking;
    }

    @Override
    public List<PiwikTracking> findPiwikTrackingsByCompanyId(long companyId) {
        String queryString = "SELECT n FROM PiwikTracking n WHERE n.companyId = ?1 ORDER BY n.groupId ASC";
        Object[] queryObject = new Object[]{companyId};

        List<PiwikTracking> piwikTrackings = findByQuery(queryString, queryObject);

        return piwikTrackings;
    }

    @Override
    public PiwikTracking findPiwikTrackingByGroupId(long companyId, long groupId) {

        List<PiwikTracking> piwikTrackings = findPiwikTrackingsByGroupId(companyId, groupId);
        
        PiwikTracking piwikTracking = null;
        
        if(piwikTrackings.size() > 0) {
        	piwikTracking = piwikTrackings.get(0);
        }

        return piwikTracking;
    }
    
    @Override
    public List<PiwikTracking> findPiwikTrackingsByGroupId(long companyId, long groupId) {
        String queryString = "SELECT n FROM PiwikTracking n WHERE n.companyId = ?1 AND n.groupId = ?2 ORDER BY "
                + "n.groupId ASC";

        Object[] queryObject = new Object[]{companyId, groupId};

        List<PiwikTracking> piwikTrackings = findByQuery(queryString, queryObject);

        return piwikTrackings;
    }
    
    @Override
    public List<PiwikTracking> findPiwikTrackingsByPiwikTrackingCode(long companyId, String piwikTrackingCode) {
        String queryString = "SELECT n FROM PiwikTracking n WHERE n.companyId = ?1 AND n.piwikTrackingCode = ?2 ORDER BY "
                + "n.groupId ASC";

        Object[] queryObject = new Object[]{companyId, piwikTrackingCode};

        List<PiwikTracking> piwikTrackings = findByQuery(queryString, queryObject);

        return piwikTrackings;
    }

}
